@@ -1,6 +1,6 @@
 package Net::Douban::Tag;
 {
-    $Net::Douban::Tag::VERSION = '1.13';
+    $Net::Douban::Tag::VERSION = '1.14';
 }
 
 use Carp qw/carp croak/;
@@ -8,23 +8,19 @@ use Moose::Role;
 use Net::Douban::Utils;
 use namespace::autoclean;
 
-our %api_hash = (
-    get_tags => {
-        path            => '/{cat}/subject/{subjectID}/tags',
-        optional_params => [qw/start-index max-results/],
-        method          => 'GET',
-        has_url_param   => 1,
-    },
+douban_method get_tags => {
+    path            => '/{cat}/subject/{subjectID}/tags',
+    optional_params => [qw/start-index max-results/],
+    method          => 'GET',
+    has_url_param   => 1,
+};
 
-    get_user_tags => {
-        path            => '/people/{userID}/tags?cat={cat}',
-        optional_params => [qw/start-index max-results/],
-        method          => 'GET',
-        has_url_param   => 1,
-    },
-);
-
-_build_method( __PACKAGE__, %api_hash );
+douban_method get_user_tags => {
+    path            => '/people/{userID}/tags?cat={cat}',
+    optional_params => [qw/start-index max-results/],
+    method          => 'GET',
+    has_url_param   => 1,
+};
 
 1;
 __END__
@@ -37,7 +33,7 @@ Net::Douban::Tag
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
